split_v_spaced

Function split_v_spaced 

pub fn split_v_spaced(
    area: Rect,
    constraints: &[Constraint],
    spacing: impl Into<Spacing>,
) -> (Vec<Rect>, Vec<Rect>)
Split area into stacked rows top-to-bottom, like split_v, but with a spacing-cell gap or overlap between every adjacent pair of panes; see Spacing.

See split_h_spaced for the full behavior, including the shape and meaning of the returned (panes, gaps); this is the same operation along the vertical axis.