pub fn split_v_n_spaced<const N: usize>(
area: Rect,
constraints: [Constraint; N],
spacing: impl Into<Spacing>,
) -> ([Rect; N], Vec<Rect>)Expand description
Split area into stacked rows top-to-bottom, like split_v_n, but with a spacing-cell
gap or overlap between every adjacent pair of panes, like split_v_spaced; see Spacing.
See split_h_n_spaced for the full behavior, including why gaps is a Vec rather than a
second const-generic array; this is the same operation along the vertical axis.